Function caesar_core::sender::http_client::send_info
source · pub async fn send_info(
relay: &str,
name: &str,
room_id: &str,
is_local: bool
) -> Result<TransferResponse, Box<dyn Error + Send + Sync>>Expand description
Asynchronously sends information about the sender to the specified relay.
Arguments
relay- The URL of the relay.name- The name of the sender.room_id- The ID of the room.is_local- Indicates whether the sender is local.
Returns
A Result containing a TransferResponse if the request was successful, or an error if it failed.